package com.ruoyi.web.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import java.util.ArrayList;
import java.util.List;
import java.util.Arrays;

import com.ruoyi.app.domain.TbAppUser;
import com.ruoyi.app.domain.TbMyPublish;
import com.ruoyi.app.domain.TbPublishComment;
import com.ruoyi.app.domain.TbPublishImg;
import com.ruoyi.app.service.ITbAppUserService;
import com.ruoyi.app.service.ITbPublishImgService;
import com.ruoyi.common.utils.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.aspectj.weaver.loadtime.Aj;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.app.service.ITbMyPublishService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 我的近况（发表）
 * 
 * @author Alex
 * @date 2020-10-02
 */
@Api(value = "我的近况（发表）", tags = "我的近况（发表）")
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/system/publish" )
public class TbMyPublishController extends BaseController {

    private final ITbMyPublishService iTbMyPublishService;

    @Autowired
    private ITbPublishImgService publishImgService;
    @Autowired
    private ITbAppUserService appUserService;

    /**
     * 查询我的近况 列表
     */
    @ApiOperation("查询我的发表列表")
    @PreAuthorize("@ss.hasPermi('app:publish:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbMyPublish tbMyPublish)
    {
        startPage();
        LambdaQueryWrapper<TbMyPublish> lqw = new LambdaQueryWrapper<TbMyPublish>();
        if (tbMyPublish.getAppUserId() != null){
            lqw.eq(TbMyPublish::getAppUserId ,tbMyPublish.getAppUserId());
        }
        if (StringUtils.isNotBlank(tbMyPublish.getContents())){
            lqw.like(TbMyPublish::getContents ,tbMyPublish.getContents());
        }
        if (StringUtils.isNotBlank(tbMyPublish.getMessage())){
            lqw.eq(TbMyPublish::getMessage ,tbMyPublish.getMessage());
        }
        List<TbMyPublish> list = iTbMyPublishService.list(lqw);
        return getDataTable(list);
    }

    /**
     * 导出我的近况 列表
     */
    @ApiOperation("导出我的近况 列表")
    @PreAuthorize("@ss.hasPermi('app:publish:export')" )
    @Log(title = "我的近况（我的发）" , businessType = BusinessType.EXPORT)
    @GetMapping("/export" )
    public AjaxResult export(TbMyPublish tbMyPublish) {
        LambdaQueryWrapper<TbMyPublish> lqw = new LambdaQueryWrapper<TbMyPublish>(tbMyPublish);
        List<TbMyPublish> list = iTbMyPublishService.list(lqw);
        ExcelUtil<TbMyPublish> util = new ExcelUtil<TbMyPublish>(TbMyPublish. class);
        return util.exportExcel(list, "publish" );
    }

    /**
     * 获取我的近况详细信息
     */
    @ApiOperation("获取我的近况 详细信息")
    @PreAuthorize("@ss.hasPermi('app:publish:query')" )
    @GetMapping(value = "/{id}" )
    public AjaxResult getInfo(@PathVariable("id" ) Long id) {
        TbMyPublish publish = iTbMyPublishService.getById(id);
        if (publish != null) {
            List<TbPublishImg> publishImgs = publishImgService.list(new LambdaQueryWrapper<TbPublishImg>()
                .in(TbPublishImg::getPublishId, id)
            );
            int thumbs = iTbMyPublishService.getThumbs(id);
            int comments = iTbMyPublishService.getComments(id);
            if (publish.getMessageUserId() != null) {
                TbAppUser user = appUserService.getById(publish.getMessageUserId());
                publish.setMessageUser(user.getNickName());
            }
            publish.setImgList(publishImgs);
            publish.setThumbs(thumbs);
            publish.setComments(comments);
        }
        return AjaxResult.success(publish);
    }

    /**
     * 新增我的近况
     */
    @ApiOperation("新增我的近况 ")
    @PreAuthorize("@ss.hasPermi('app:publish:add')" )
    @Log(title = "我的近况（我的发）" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbMyPublish tbMyPublish) {
        return toAjax(iTbMyPublishService.save(tbMyPublish) ? 1 : 0);
    }

    /**
     * 修改我的近况
     */
    @ApiOperation("修改我的近况 ")
    @PreAuthorize("@ss.hasPermi('app:publish:edit')" )
    @Log(title = "我的近况（我的发）" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbMyPublish tbMyPublish) {
        return toAjax(iTbMyPublishService.updateById(tbMyPublish) ? 1 : 0);
    }

    /**
     * 删除我的近况（我的发）
     */
    @ApiOperation("删除我的近况 ")
    @PreAuthorize("@ss.hasPermi('app:publish:remove')" )
    @Log(title = "我的近况（我的发）" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}" )
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(iTbMyPublishService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }



    /**
     * 获取我的近况 评论列表
     * @param id
     * @return
     */
    @ApiOperation("获取我的近况 评论列表")
    @GetMapping(value = "/listComment/{id}" )
    public TableDataInfo listComment(@PathVariable("id" ) Long id) {
        startPage();
        List<TbPublishComment> list = iTbMyPublishService.listComment(id);
        return getDataTable(list);
    }

    @ApiOperation("删除一条评论")
    @GetMapping(value = "/delComment/{id}" )
    public AjaxResult delComment(@PathVariable("id" ) Long id) {
        if (iTbMyPublishService.delComment(id)) {
            return AjaxResult.success("删除成功");
        }
        return AjaxResult.error("删除失败");
    }
}
